@@ -54,7 +54,10 @@
 
 (require 'emms)
 (require 'emms-info)
+(require 'emms-pbi)
+(require 'emms-pbi-mark)
 (require 'widget)
+(require 'wid-edit)
 
 ;; Custom
 (defgroup emms-tageditor nil
